notetools.make_accelerating_notes_with_lilypond_multipliers
===========================================================

.. autofunction:: abjad.tools.notetools.make_accelerating_notes_with_lilypond_multipliers.make_accelerating_notes_with_lilypond_multipliers
